

#ifndef SCALE_GRAPHVIZ_H
#define SCALE_GRAPHVIZ_H


#include <scale/commons.h>
#include <scale/heap.h>
#include <scale/buffer.h>
#include <scale/btree.h>


sbuffer_t *s_heap_graphviz(sheap_t *heap);
sbuffer_t *s_btree_graphviz(sbtree_t *bt);


#endif /* SCALE_GRAPHVIZ_H */



